This package provides tools for data-driven analytical statistical inference for Local Polynomial Regression (LPR) estimators and Kernel Density Estimation (KDE): lprobust to construct local-polynomial point estimators and robust confidence intervals, lpbwselect to perform bandwidth selection for the different procedures implemented.
| Package: | nprobust |
| Type: | Package |
| Version: | 0.0.1 |
| Date: | 2016-11-06 |
| License: | GPL-2 |
Function for LPR statistical inference: lprobust
Function for LPR bandwidths selection: lpbwselect
Function for KDE statistical inference: kdrobust
Function for KDE bandwidths selection: kdbwselect